<?php
/**
    * A custom confirmed Order WooCommerce Email class
    *
    * @since 0.1
    * @extends \WC_Email
    */
class WC_Shipping_Order_Email extends WC_Email {


    /**
        * Set email defaults
        *
        * @since 0.1
        */
    public function __construct() {

        $this->id = 'wc_shipping_order';

        $this->title = __('Order Delivery Information');

        $this->description = __('Order Delivery Information Desc','datalogics_shipping');

        $this->heading = __('Order Delivery Information Heading','datalogics_shipping');
        $this->subject =  __('Order Delivery Information Subject','datalogics_shipping');

        //var_dump(dirname( __FILE__ ).'/templates/emails/customer-note.php');
        $this->template_base = dirname( __FILE__ ).'/';
        $this->template_html  = 'templates/emails/customer-note.php';
        $this->template_plain = 'templates/emails/plain/customer-note.php';

        //add_action( 'woocommerce_order_status_pending_to_order_confirmed', array( $this, 'trigger' ) );
        //add_action( 'woocommerce_order_status_processing_to_order_confirmed', array( $this, 'trigger' ) );

        add_action( 'datalogics_shipping_customer_shipping_email', array( $this, 'trigger' ) );

        
        // this sets the recipient to the settings defined below in init_form_fields()
        //$this->recipient = $this->get_option( 'recipient' );
        $this->customer_email = true;

        // if none was entered, just use the WP admin email as a fallback
        //if ( ! $this->recipient ) {
            //$this->recipient = null;
        //}

        // Call parent constructor to load any other defaults not explicity defined here
        parent::__construct();

        
    }


    /**
        * Determine if the email should actually be sent and setup email merge variables
        *
        * @since 0.1
        * @param int $order_id
        */
    public function trigger( $order_id ) {
            // bail if no order ID is present

           
        if ( ! $order_id )
            return;

        if ( $order_id ) {
            $this->object       = wc_get_order( $order_id );

            
            if ( version_compare( '3.0.0', WC()->version, '>' ) ) {
                $order_email = $this->object->billing_email;
            } else {
                $order_email = $this->object->get_billing_email();
            }
    
            $this->recipient = $order_email;


            $tracking = '';

            foreach($this->object->meta_data as $meta) {
                

                $meta = (array)$meta;
                $meta = end($meta);

                if ($meta['key']=='datalogics_shipping') {

                    $data = json_decode($meta['value']);
                    foreach($data as $shipment) {
                        $tracking = $shipment->tracking_number;
                    }

                }                


                
            }

            //var_dump($this->recipient,$tracking);


            $this->find['tracking']      = '{tracking}';
            $this->find['order-number']    = '{order_number}';

            $this->replace['tracking']   = $tracking;
            $this->replace['order-number'] = $this->object->get_order_number();
        }


        if ( ! $this->is_enabled() || ! $this->get_recipient() || $tracking=='') {
            return;
        }


        // woohoo, send the email!
        $this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
    }


    /**
        * get_content_html function.
        *
        * @since 0.1
        * @return string
        */
    public function get_content_html() {
        return wc_get_template_html( $this->template_html, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => false,
			'email'			=> $this
		), '', $this->template_base );
    }


    /**
        * get_content_plain function.
        *
        * @since 0.1
        * @return string
        */
    public function get_content_plain() {
        return wc_get_template_html( $this->template_plain, array(
			'order'         => $this->object,
			'email_heading' => $this->get_heading(),
			'sent_to_admin' => false,
			'plain_text'    => true,
			'email'			=> $this
		), '', $this->template_base );
    }


    /**
        * Initialize Settings Form Fields
        *
        * @since 2.0
        */
    public function init_form_fields() {

        $this->form_fields = array(
            'enabled'    => array(
                'title'   => 'Enable/Disable',
                'type'    => 'checkbox',
                'label'   => 'Enable this email notification',
                'default' => 'yes'
            ),
            // 'recipient'  => array(
            //     'title'       => 'Recipient(s)',
            //     'type'        => 'text',
            //     'description' => sprintf( 'Enter recipients (comma separated) for this email. Defaults to <code>%s</code>.', esc_attr( get_option( 'admin_email' ) ) ),
            //     'placeholder' => '',
            //     'default'     => ''
            // ),
            'subject'    => array(
                'title'       => 'Subject',
                'type'        => 'text',
                'description' => sprintf( 'This controls the email subject line. Leave blank to use the default subject: <code>%s</code>.', $this->subject ),
                'placeholder' => '',
                'default'     => ''
            ),
            'heading'    => array(
                'title'       => 'Email Heading',
                'type'        => 'text',
                'description' => sprintf( __( 'This controls the main heading contained within the email notification. Leave blank to use the default heading: <code>%s</code>.' ), $this->heading ),
                'placeholder' => '',
                'default'     => ''
            ),
            'email_type' => array(
                'title'       => 'Email type',
                'type'        => 'select',
                'description' => 'Choose which format of email to send.',
                'default'     => 'html',
                'class'       => 'email_type',
                'options'     => array(
                    'plain'     => __( 'Plain text', 'woocommerce' ),
                    'html'      => __( 'HTML', 'woocommerce' ),
                    'multipart' => __( 'Multipart', 'woocommerce' ),
                )
            )
        );
    }


} // end \WC_confirmed_Order_Email class

?>