<?php

$updater_run = false;

//if( ! class_exists( 'Datalogics_Version_Checker' ) && strpos($_SERVER['REQUEST_URI'],'plugins.php')) {
if( ! class_exists( 'datalogicsUpdater' ) && strpos($_SERVER['REQUEST_URI'],'plugins.php') ) {

	class datalogicsUpdater{

		public $plugin_slug;
		public $version;
		public $cache_key;
		public $cache_allowed;

		public function __construct() {

			$this->plugin_slug = plugin_basename( __DIR__ );
			$this->version = DATALOGICS_ARGS['dls_version'];
			$this->cache_key = 'datalogics';
			$this->cache_allowed = false;

            //error_log('slog:'.$this->plugin_slug .' version:'.$this->version );
 
			add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
            add_filter( 'pre_set_site_transient_update_plugins', array($this, 'update'));
			add_filter( 'site_transient_update_plugins', array( $this, 'update' ));
			add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

		}

		public function request(){

            //error_log('request');

			$remote = get_transient( $this->cache_key );


			if( false === $remote || ! $this->cache_allowed ) {

				if (DATALOGICS_COMPANY == 'POSTIL') {

					$url = 'https://docs.datalogics.co.il/downloads/israel_post_info.json';

				} else {
					$url = 'https://docs.datalogics.co.il/downloads/info.json';
				}

				$remote = wp_remote_get(
					$url,
					array(
						'timeout' => 60,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);






				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}

                $body = $remote['http_response']->get_response_object()->body;

				set_transient( $this->cache_key, $body, DAY_IN_SECONDS );

			}

			$remote = json_decode( wp_remote_retrieve_body( $remote ) );

			return $remote;

		}


		function info( $res, $action, $args ) {

            //error_log('inside datalogics uploader action:'.$action);

			// print_r( $action );
			// print_r( $args );

			// do nothing if you're not getting plugin information right now
			if( 'plugin_information' !== $action ) {
				return $res;
			}

			// do nothing if it is not our plugin
			if( $this->plugin_slug !== $args->slug ) {
				return $res;
			}

			// get updates
			$remote = $this->request();

			if( ! $remote ) {
				return $res;
			}

			$res = new stdClass();

			$res->name = $remote->name;
			$res->slug = $remote->slug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = $remote->author;
			$res->author_profile = $remote->author_profile;
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;
			$res->last_updated = $remote->last_updated;

			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
			);

			if( ! empty( $remote->banners ) ) {
				$res->banners = array(
					'low' => $remote->banners->low,
					'high' => $remote->banners->high
				);
			}

			return $res;

		}

		public function update( $transient ) {

            //error_log('inside datalogics update function:');

			if ( empty($transient->checked ) ) {
				return $transient;
			}

            

			$remote = $this->request();


            //error_log($this->version . '==========='. $remote->version);

			
			//var_dump(str_replace("version.php","datalogics.php",plugin_basename( __FILE__ )));

			if(
				$remote
				&& version_compare( $this->version, $remote->version, '<' )
				&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<=' )
				&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
			) {

				

				$res = new stdClass();
				$res->slug = $this->plugin_slug;
				$res->plugin = str_replace("version.php","datalogics.php",plugin_basename( __FILE__ )); // misha-update-plugin/misha-update-plugin.php
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url; 
				$res->requires_plugins = ["woocommerce"]; 

				// var_dump($res);


                //error_log('newww' . $res->new_version . '=='.$res->package);
                
                //var_dump(plugin_basename( __FILE__ ));


				$transient->response[ $res->plugin ] = $res;

				//var_dump($transient);

	        }

			return $transient;

		}

		public function purge( $upgrader, $options ){

            //error_log('===========purge');

			if (
				$this->cache_allowed
				&& 'update' === $options['action']
				&& 'plugin' === $options[ 'type' ]
			) {
				// just clean the cache when new plugin version is installed
				delete_transient( $this->cache_key );
			}

		}


	}

}

if ($updater_run == false && strpos($_SERVER['REQUEST_URI'],'plugins.php')) {

    $updater = new datalogicsUpdater();
	$updater_run = true;   

}




function datalogics_add_custom_cron_intervals($schedules) {

    // if(!isset($schedules["datalogics_version_every_five_minutes"]))
    // {
    //     $schedules['datalogics_version_every_five_minutes'] = array(
    //         'interval' => 300, // 300 seconds (5 minutes)
    //         'display'  => __('Every 5 Minutes', 'datalogics')
    //     );
    // }
    
    return $schedules;
}

add_filter('cron_schedules', 'datalogics_add_custom_cron_intervals'); 

//wp_clear_scheduled_hook('datalogics_check_for_updates_schedule');

// if (!wp_next_scheduled('datalogics_version_every_five_minutes')) {
//     wp_schedule_event(time(), 'datalogics_version_every_five_minutes', 'datalogics_check_for_updates_schedule');
// }

add_action ('datalogics_check_for_updates_schedule', 'datalogics_check_for_updates' );

function datalogics_check_for_updates() {

    //$updater = new datalogicsUpdater();

}






// Display an update notice if an update is available.
function datalogics_update_notice() {
    if (get_transient('datalogics_update_available')) {
        echo '<div class="notice notice-success is-dismissible">
            <p>An update is available for Datalogics. <a href="' . admin_url('update.php?action=upgrade-plugin&plugin=datalogics/datalogics.php') . '">Update now</a></p>
        </div>';
        delete_transient('datalogics_update_available');
    }
}
add_action('admin_notices', 'datalogics_update_notice');




?>